@@ -49,7 +49,7 @@ class ImageProcessor:
         pdf_fh = open(pdf, "rb")
         sig_tmp_fh = None
 
-        pdf = pypdf.PdfFileReader(pdf_fh)
+        pdf = pypdf.PdfReader(pdf_fh)
         # Set y1 to pixels from top of page
         y1 = int(pdf.getPage(page_num).mediaBox[3] - y)
         print(pdf.getPage(page_num).mediaBox)
@@ -57,7 +57,7 @@ class ImageProcessor:
         writer = pypdf.PdfFileWriter()
         sig_tmp_filename = None
 
-        for i in range(0, pdf.getNumPages()):
+        for i in range(0, len(pdf.pages)):
             page = pdf.getPage(i)
 
             if i == page_num:
@@ -76,7 +76,7 @@ class ImageProcessor:
 
                 # Merge PDF in to original page
                 sig_tmp_fh = open(sig_tmp_filename, "rb")
-                sig_tmp_pdf = pypdf.PdfFileReader(sig_tmp_fh)
+                sig_tmp_pdf = pypdf.PdfReader(sig_tmp_fh)
                 sig_page = sig_tmp_pdf.getPage(0)
                 sig_page.mediaBox = page.mediaBox
                 page.mergePage(sig_page)
@@ -119,8 +119,8 @@ class ImageProcessor:
     def open_pdf(self, filename):
         try:
             pdfFileObject = open(filename, "rb")
-            pdf_reader = pypdf.PdfFileReader(pdfFileObject, strict=False)
-            self.PAGE_COUNT = pdf_reader.numPages
+            pdf_reader = pypdf.PdfReader(pdfFileObject, strict=False)
+            self.PAGE_COUNT = len(pdf_reader.pages)
             return pdf_reader
         except pypdf.errors.PdfReadError:
             print("PDF not fully written - no EOF Marker")
